@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -36,7 +36,7 @@ public:
     SieveImapInstanceInterface *sieveImapInstanceInterface() const;
     QVector<KSieveUi::SieveImapInstance> sieveImapInstanceList() const;
 private:
-    SieveImapInstanceInterface *mInterface;
+    SieveImapInstanceInterface *mInterface = nullptr;
 };
 }
 
