@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2018-2019 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -17,14 +17,12 @@
    Boston, MA 02110-1301, USA.
 */
 
-
 #ifndef ABSTRACTSELECTEMAILLINEEDIT_H
 #define ABSTRACTSELECTEMAILLINEEDIT_H
 
 #include <QWidget>
 #include "ksieveui_export.h"
-namespace KSieveUi
-{
+namespace KSieveUi {
 class KSIEVEUI_EXPORT AbstractSelectEmailLineEdit : public QWidget
 {
     Q_OBJECT
